==> jc-1.4.0.tar.gz: ppg/cmds/DropCmd.h <==
// public class ppg.cmds.DropCmd

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 7817fbe70a3a275b ppg_cmds_DropCmd

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_ppg_cmds_DropCmd_H_
#define _JC_ppg_cmds_DropCmd_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_Vector$object;
struct _jc_ppg_atoms_Production$object;
struct _jc_ppg_util_CodeWriter$object;

// Typedefs
typedef struct _jc_ppg_cmds_DropCmd$sub_refs	_jc_ppg_cmds_DropCmd$sub_refs;
typedef struct _jc_ppg_cmds_DropCmd$sub_nonrefs	_jc_ppg_cmds_DropCmd$sub_nonrefs;
typedef struct _jc_ppg_cmds_DropCmd$refs	_jc_ppg_cmds_DropCmd$refs;
typedef struct _jc_ppg_cmds_DropCmd$nonrefs	_jc_ppg_cmds_DropCmd$nonrefs;
typedef struct _jc_ppg_cmds_DropCmd$object	_jc_ppg_cmds_DropCmd$object;

typedef const struct _jc_ppg_cmds_DropCmd$vmethods	_jc_ppg_cmds_DropCmd$vmethods;
typedef const struct _jc_ppg_cmds_DropCmd$vtable	_jc_ppg_cmds_DropCmd$vtable;
typedef const struct _jc_ppg_cmds_DropCmd$vtype	_jc_ppg_cmds_DropCmd$vtype;

// Constructors
extern void _jc_ppg_cmds_DropCmd$method$_init$7daa05b6e050118a(_jc_env *, struct _jc_ppg_cmds_DropCmd$object *, struct _jc_java_util_Vector$object *);
extern void _jc_ppg_cmds_DropCmd$method$_init$366f936045042a22(_jc_env *, struct _jc_ppg_cmds_DropCmd$object *, struct _jc_ppg_atoms_Production$object *);

// Virtual methods
extern struct _jc_ppg_atoms_Production$object *_jc_ppg_cmds_DropCmd$method$getProduction$794612980e712f24(_jc_env *, struct _jc_ppg_cmds_DropCmd$object *);
extern struct _jc_java_util_Vector$object *_jc_ppg_cmds_DropCmd$method$getSymbols$627c4ebd5ffbff58(_jc_env *, struct _jc_ppg_cmds_DropCmd$object *);
extern jboolean _jc_ppg_cmds_DropCmd$method$isProdDrop$86ea57a6db2e3a03(_jc_env *, struct _jc_ppg_cmds_DropCmd$object *);
extern jboolean _jc_ppg_cmds_DropCmd$method$isSymbolDrop$69e4de0fe529c5eb(_jc_env *, struct _jc_ppg_cmds_DropCmd$object *);
extern void _jc_ppg_cmds_DropCmd$method$unparse$3d4a69bf2fda9799(_jc_env *, struct _jc_ppg_cmds_DropCmd$object *, struct _jc_ppg_util_CodeWriter$object *);

// Virtual method descriptors
extern _jc_method _jc_ppg_cmds_DropCmd$method_info$getProduction$794612980e712f24;
extern _jc_method _jc_ppg_cmds_DropCmd$method_info$getSymbols$627c4ebd5ffbff58;
extern _jc_method _jc_ppg_cmds_DropCmd$method_info$isProdDrop$86ea57a6db2e3a03;
extern _jc_method _jc_ppg_cmds_DropCmd$method_info$isSymbolDrop$69e4de0fe529c5eb;
extern _jc_method _jc_ppg_cmds_DropCmd$method_info$unparse$3d4a69bf2fda9799;

// Virtual methods structure
struct _jc_ppg_cmds_DropCmd$vmethods {
	struct _jc_ppg_atoms_Production$object	*(*getProduction$794612980e712f24)(_jc_env *, struct _jc_ppg_cmds_DropCmd$object *);
	struct _jc_java_util_Vector$object	*(*getSymbols$627c4ebd5ffbff58)(_jc_env *, struct _jc_ppg_cmds_DropCmd$object *);
	jboolean	(*isProdDrop$86ea57a6db2e3a03)(_jc_env *, struct _jc_ppg_cmds_DropCmd$object *);
	jboolean	(*isSymbolDrop$69e4de0fe529c5eb)(_jc_env *, struct _jc_ppg_cmds_DropCmd$object *);
	void	(*unparse$3d4a69bf2fda9799)(_jc_env *, struct _jc_ppg_cmds_DropCmd$object *, struct _jc_ppg_util_CodeWriter$object *);
};

// Vtable
struct _jc_ppg_cmds_DropCmd$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_ppg_cmds_DropCmd$vmethods	ppg_cmds_DropCmd;
};

// Vtype
struct _jc_ppg_cmds_DropCmd$vtype {
	_jc_type			type;
	_jc_ppg_cmds_DropCmd$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_ppg_cmds_DropCmd$sub_refs {
	struct _jc_ppg_atoms_Production$object	*prod;
	struct _jc_java_util_Vector$object	*sym;
};

// Reference instance fields (object)
struct _jc_ppg_cmds_DropCmd$refs {
    _jc_ppg_cmds_DropCmd$sub_refs	ppg_cmds_DropCmd;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_ppg_cmds_DropCmd$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_ppg_cmds_DropCmd$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_ppg_cmds_DropCmd$sub_nonrefs	ppg_cmds_DropCmd;
};

// Object instance structure
struct _jc_ppg_cmds_DropCmd$object {
	_jc_ppg_cmds_DropCmd$refs	refs[0];
	_jc_word		lockword;
	_jc_ppg_cmds_DropCmd$vtype	*vtype;
	_jc_ppg_cmds_DropCmd$nonrefs	nonrefs;
};

// Type structure
extern _jc_ppg_cmds_DropCmd$vtype _jc_ppg_cmds_DropCmd$type;

// Array types class info structures
_JC_DECL_ARRAYS(ppg_cmds_DropCmd, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_ppg_cmds_DropCmd$class_object;

#endif	/* _JC_ppg_cmds_DropCmd_H_ */

==> jc-1.4.6.tar.gz: ppg/cmds/DropCmd.h <==
// public class ppg.cmds.DropCmd

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 7817fbe70a3a275b ppg_cmds_DropCmd

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_ppg_cmds_DropCmd_H_
#define _JC_ppg_cmds_DropCmd_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_Vector$object;
struct _jc_ppg_atoms_Production$object;
struct _jc_ppg_util_CodeWriter$object;

// Typedefs
typedef struct _jc_ppg_cmds_DropCmd$sub_refs	_jc_ppg_cmds_DropCmd$sub_refs;
typedef struct _jc_ppg_cmds_DropCmd$sub_nonrefs	_jc_ppg_cmds_DropCmd$sub_nonrefs;
typedef struct _jc_ppg_cmds_DropCmd$refs	_jc_ppg_cmds_DropCmd$refs;
typedef struct _jc_ppg_cmds_DropCmd$nonrefs	_jc_ppg_cmds_DropCmd$nonrefs;
typedef struct _jc_ppg_cmds_DropCmd$object	_jc_ppg_cmds_DropCmd$object;

typedef const struct _jc_ppg_cmds_DropCmd$vmethods	_jc_ppg_cmds_DropCmd$vmethods;
typedef const struct _jc_ppg_cmds_DropCmd$vtable	_jc_ppg_cmds_DropCmd$vtable;
typedef const struct _jc_ppg_cmds_DropCmd$vtype	_jc_ppg_cmds_DropCmd$vtype;

// Constructors
extern void _jc_ppg_cmds_DropCmd$method$_init$7daa05b6e050118a(_jc_env *, struct _jc_ppg_cmds_DropCmd$object *, struct _jc_java_util_Vector$object *) _JC_JCNI_ATTR;
extern void _jc_ppg_cmds_DropCmd$method$_init$366f936045042a22(_jc_env *, struct _jc_ppg_cmds_DropCmd$object *, struct _jc_ppg_atoms_Production$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_ppg_atoms_Production$object *_jc_ppg_cmds_DropCmd$method$getProduction$794612980e712f24(_jc_env *, struct _jc_ppg_cmds_DropCmd$object *) _JC_JCNI_ATTR;
extern struct _jc_java_util_Vector$object *_jc_ppg_cmds_DropCmd$method$getSymbols$627c4ebd5ffbff58(_jc_env *, struct _jc_ppg_cmds_DropCmd$object *) _JC_JCNI_ATTR;
extern jboolean _jc_ppg_cmds_DropCmd$method$isProdDrop$86ea57a6db2e3a03(_jc_env *, struct _jc_ppg_cmds_DropCmd$object *) _JC_JCNI_ATTR;
extern jboolean _jc_ppg_cmds_DropCmd$method$isSymbolDrop$69e4de0fe529c5eb(_jc_env *, struct _jc_ppg_cmds_DropCmd$object *) _JC_JCNI_ATTR;
extern void _jc_ppg_cmds_DropCmd$method$unparse$3d4a69bf2fda9799(_jc_env *, struct _jc_ppg_cmds_DropCmd$object *, struct _jc_ppg_util_CodeWriter$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_ppg_cmds_DropCmd$method_info$getProduction$794612980e712f24;
extern _jc_method _jc_ppg_cmds_DropCmd$method_info$getSymbols$627c4ebd5ffbff58;
extern _jc_method _jc_ppg_cmds_DropCmd$method_info$isProdDrop$86ea57a6db2e3a03;
extern _jc_method _jc_ppg_cmds_DropCmd$method_info$isSymbolDrop$69e4de0fe529c5eb;
extern _jc_method _jc_ppg_cmds_DropCmd$method_info$unparse$3d4a69bf2fda9799;

// Virtual methods structure
struct _jc_ppg_cmds_DropCmd$vmethods {
	struct _jc_ppg_atoms_Production$object	*(*getProduction$794612980e712f24)(_jc_env *, struct _jc_ppg_cmds_DropCmd$object *) _JC_JCNI_ATTR;
	struct _jc_java_util_Vector$object	*(*getSymbols$627c4ebd5ffbff58)(_jc_env *, struct _jc_ppg_cmds_DropCmd$object *) _JC_JCNI_ATTR;
	jboolean	(*isProdDrop$86ea57a6db2e3a03)(_jc_env *, struct _jc_ppg_cmds_DropCmd$object *) _JC_JCNI_ATTR;
	jboolean	(*isSymbolDrop$69e4de0fe529c5eb)(_jc_env *, struct _jc_ppg_cmds_DropCmd$object *) _JC_JCNI_ATTR;
	void	(*unparse$3d4a69bf2fda9799)(_jc_env *, struct _jc_ppg_cmds_DropCmd$object *, struct _jc_ppg_util_CodeWriter$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_ppg_cmds_DropCmd$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_ppg_cmds_DropCmd$vmethods	ppg_cmds_DropCmd;
};

// Vtype
struct _jc_ppg_cmds_DropCmd$vtype {
	_jc_type			type;
	_jc_ppg_cmds_DropCmd$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_ppg_cmds_DropCmd$sub_refs {
	struct _jc_ppg_atoms_Production$object	*prod;
	struct _jc_java_util_Vector$object	*sym;
};

// Reference instance fields (object)
struct _jc_ppg_cmds_DropCmd$refs {
    _jc_ppg_cmds_DropCmd$sub_refs	ppg_cmds_DropCmd;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_ppg_cmds_DropCmd$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_ppg_cmds_DropCmd$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_ppg_cmds_DropCmd$sub_nonrefs	ppg_cmds_DropCmd;
};

// Object instance structure
struct _jc_ppg_cmds_DropCmd$object {
	_jc_ppg_cmds_DropCmd$refs	refs[0];
	_jc_word		lockword;
	_jc_ppg_cmds_DropCmd$vtype	*vtype;
	_jc_ppg_cmds_DropCmd$nonrefs	nonrefs;
};

// Type structure
extern _jc_ppg_cmds_DropCmd$vtype _jc_ppg_cmds_DropCmd$type;

// Array types class info structures
_JC_DECL_ARRAYS(ppg_cmds_DropCmd, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_ppg_cmds_DropCmd$class_object;

#endif	/* _JC_ppg_cmds_DropCmd_H_ */
